@@ -28,7 +28,6 @@
 #include <qcombobox.h>
 #include <qsplitter.h>
 #include <qfileinfo.h>
-#include <q3multilineedit.h>
 #include <qtextstream.h>
 #include <QMenu>
 #include <qtooltip.h>
@@ -37,9 +36,10 @@
 #include <qfontdatabase.h>
 #include <qfile.h>
 #include <QLinkedList>
+#include <q3mimefactory.h>
 
 // KDE
-#include <k3command.h>
+#include <kundostack.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kaction.h>
@@ -320,7 +320,7 @@ void KImageMapEditor::setReadWrite(bool)
 void KImageMapEditor::setModified(bool modified)
 {
     // get a handle on our Save action and make sure it is valid
-    QAction *save = actionCollection()->action(KStandardAction::stdName(KStandardAction::Save));
+    QAction *save = actionCollection()->action(KStandardAction::name(KStandardAction::Save));
     if (!save)
         return;
 
@@ -343,16 +343,14 @@ KConfig *KImageMapEditor::config()
 }
 
 void KImageMapEditor::readConfig(const KConfigGroup &config) {
-  KConfigGroup data = config;
-  data.changeGroup( "Data" );
+  KConfigGroup data = config.parent().group( "Data" );
   recentFilesAction->loadEntries( data );
 }
 
 void KImageMapEditor::writeConfig(KConfigGroup& config) {
   config.writeEntry("highlightareas",highlightAreasAction->isChecked());
   config.writeEntry("showalt",showAltAction->isChecked());
-  KConfigGroup data = config;
-  data.changeGroup( "Data" );
+  KConfigGroup data = config.parent().group( "Data" );
   recentFilesAction->saveEntries( data );
   saveLastURL(config);
 
@@ -386,7 +384,9 @@ void KImageMapEditor::slotConfigChanged()
   int newHeight=group.readEntry("maximum-preview-height",50);
   group = config()->group("General Options");
   _commandHistory->setUndoLimit(group.readEntry("undo-level",100));
+#if 0
   _commandHistory->setRedoLimit(group.readEntry("redo-level",100));
+#endif
   Area::highlightArea = group.readEntry("highlightareas",true);
   highlightAreasAction->setChecked(Area::highlightArea);
   Area::showAlt = group.readEntry("showalt",true);
@@ -502,7 +502,9 @@ void KImageMapEditor::setupActions()
   deleteAction->setEnabled(false);
 
   // Edit Undo/Redo
-  _commandHistory = new K3CommandHistory( actionCollection(), true);
+  _commandHistory = new KUndoStack(this);
+  _commandHistory->createUndoAction(actionCollection());
+  _commandHistory->createRedoAction(actionCollection());
 
   // Edit Properties
     areaPropertiesAction  = new KAction(i18n("Pr&operties"), this);
@@ -2451,8 +2453,8 @@ void KImageMapEditor::slotCut()
 
   copyArea= static_cast< AreaSelection* > (currentSelected->clone());
   pasteAction->setEnabled(true);
-  K3Command *command= new CutCommand(this,*currentSelected);
-  commandHistory()->addCommand( command ,true);
+  QUndoCommand *command= new CutCommand(this,*currentSelected);
+  commandHistory()->push(command);
 }
 
 
@@ -2461,8 +2463,8 @@ void KImageMapEditor::slotDelete()
   if ( 0 == currentSelected->count() )
     return;
 
-  K3Command *command= new DeleteCommand(this,*currentSelected);
-  commandHistory()->addCommand( command ,true);
+  QUndoCommand *command= new DeleteCommand(this,*currentSelected);
+  commandHistory()->push(command);
 }
 
 void KImageMapEditor::slotCopy()
@@ -2488,7 +2490,7 @@ void KImageMapEditor::slotPaste()
       return;
 
   AreaSelection *a=static_cast< AreaSelection* > (copyArea->clone());
-  commandHistory()->addCommand( new PasteCommand(this,*a),true);
+  commandHistory()->push(new PasteCommand(this,*a));
   delete a;
 //	addAreaAndEdit(a);
 }
@@ -2572,8 +2574,8 @@ void KImageMapEditor::slotMoveUp()
   selected()->setMoving(true);
   selected()->moveBy(0,-1);
 
-  commandHistory()->addCommand(
-    new MoveCommand( this, selected(), r.topLeft() ) ,true );
+  commandHistory()->push(
+    new MoveCommand( this, selected(), r.topLeft() ));
   selected()->setMoving(false);
   slotAreaChanged(selected());
   slotUpdateSelectionCoords();
@@ -2585,8 +2587,8 @@ void KImageMapEditor::slotMoveDown()
   selected()->setMoving(true);
   selected()->moveBy(0,1);
 
-  commandHistory()->addCommand(
-    new MoveCommand( this, selected(), r.topLeft() ) ,true );
+  commandHistory()->push(
+    new MoveCommand( this, selected(), r.topLeft() ));
   selected()->setMoving(false);
   slotAreaChanged(selected());
   slotUpdateSelectionCoords();
@@ -2599,8 +2601,8 @@ void KImageMapEditor::slotMoveLeft()
   selected()->setMoving(true);
   selected()->moveBy(-1,0);
 
-  commandHistory()->addCommand(
-    new MoveCommand( this, selected(), r.topLeft() ) ,true );
+  commandHistory()->push(
+    new MoveCommand( this, selected(), r.topLeft() ));
   selected()->setMoving(false);
   slotAreaChanged(selected());
   slotUpdateSelectionCoords();
@@ -2612,8 +2614,8 @@ void KImageMapEditor::slotMoveRight()
   selected()->setMoving(true);
   selected()->moveBy(1,0);
 
-  commandHistory()->addCommand(
-    new MoveCommand( this, selected(), r.topLeft() ) ,true );
+  commandHistory()->push(
+    new MoveCommand( this, selected(), r.topLeft() ));
   selected()->setMoving(false);
   slotAreaChanged(selected());
   slotUpdateSelectionCoords();
@@ -2634,8 +2636,8 @@ void KImageMapEditor::slotIncreaseHeight()
 
   selected()->setRect(r);
 
-  commandHistory()->addCommand(
-    new ResizeCommand( this, selected(), oldArea ) ,true );
+  commandHistory()->push(
+    new ResizeCommand( this, selected(), oldArea ));
   slotAreaChanged(selected());
   slotUpdateSelectionCoords();
 }
@@ -2650,8 +2652,8 @@ void KImageMapEditor::slotDecreaseHeight()
 
   selected()->setRect(r);
 
-  commandHistory()->addCommand(
-    new ResizeCommand( this, selected(), oldArea ) ,true );
+  commandHistory()->push(
+    new ResizeCommand( this, selected(), oldArea ));
   slotAreaChanged(selected());
   slotUpdateSelectionCoords();
 }
@@ -2665,8 +2667,8 @@ void KImageMapEditor::slotIncreaseWidth()
 
   selected()->setRect(r);
 
-  commandHistory()->addCommand(
-    new ResizeCommand( this, selected(), oldArea ) ,true );
+  commandHistory()->push(
+    new ResizeCommand( this, selected(), oldArea ));
   slotAreaChanged(selected());
   slotUpdateSelectionCoords();
 }
@@ -2680,8 +2682,8 @@ void KImageMapEditor::slotDecreaseWidth()
 
   selected()->setRect(r);
 
-  commandHistory()->addCommand(
-    new ResizeCommand( this, selected(), oldArea ) ,true );
+  commandHistory()->push(
+    new ResizeCommand( this, selected(), oldArea ));
   slotAreaChanged(selected());
   slotUpdateSelectionCoords();
 }
